package com.dhcc.finance.main.service;

import java.util.List;

import com.dhcc.common.model.CurrencyMeta;
import com.dhcc.common.model.response.RestfulResponse;
import com.dhcc.finance.main.domain.CwBdVouchtempcom;
import com.dhcc.finance.main.model.CwBdVouchtempcomLike;
import com.dhcc.finance.main.model.FileUploadRequest;
import com.github.pagehelper.PageInfo;

public interface CwBdVouchtempcomService {
/**
 * 功能描述:模糊查询
 * @param cwBdVouchtempcomLike
 * @param pageNum
 * @param pageSize
 * @param navigatePages
 * @return RestfulResponse<PageInfo<CwBdVouchtempcom>,CurrencyMeta>
 *@author baiyc
 *@date 2019年4月5日 下午8:26:30
 *@修改日志:
 */
	RestfulResponse<PageInfo<CwBdVouchtempcom>, CurrencyMeta> searchCwBdVouchtempcomByNameLike(
			CwBdVouchtempcomLike cwBdVouchtempcomLike, int pageNum, int pageSize, int navigatePages);
	/**
	 * 功能描述:凭证管理新增
	 * @param cwBdVouchtempcom
	 * @return RestfulResponse<Object,CurrencyMeta>
	 *@author baiyc
	 *@date 2019年4月5日 下午8:26:48
	 *@修改日志:
	 */

	RestfulResponse<Object, CurrencyMeta> addCwBdVouchtempcom(CwBdVouchtempcom cwBdVouchtempcom);
	/**
	 * 功能描述:修改凭证管理
	 * @param cwBdVouchtempcom
	 * @return RestfulResponse<Object,CurrencyMeta>
	 *@author baiyc
	 *@date 2019年4月5日 下午8:27:07
	 *@修改日志:
	 */

	RestfulResponse<Object, CurrencyMeta> updateCwBdVouchtempcomByPk(CwBdVouchtempcom cwBdVouchtempcom);
	/**
	 * 功能描述:删除凭证管理
	 * @param pkVouchtempcom
	 * @return RestfulResponse<Object,CurrencyMeta>
	 *@author baiyc
	 *@date 2019年4月5日 下午8:27:24
	 *@修改日志:
	 */

	RestfulResponse<Object, CurrencyMeta> deleteCwBdVouchtempcomByPk(String pkVouchtempcom);
	/**
	 * 功能描述:查询所有信息
	 * @return RestfulResponse<List<CwBdVouchtempcom>,CurrencyMeta>
	 *@author baiyc
	 *@date 2019年4月5日 下午8:27:40
	 *@修改日志:
	 */

	RestfulResponse<List<CwBdVouchtempcom>, CurrencyMeta> searchCwBdVouchtempcomInfo();
	/**
	 * 功能描述:Excel导入
	 * @param fileUploadRequest
	 * @param type
	 * @return RestfulResponse<String,CurrencyMeta>
	 *@author baiyc
	 *@date 2019年4月10日 上午9:07:25
	 *@修改日志:
	 */
	
	RestfulResponse<String,CurrencyMeta> uploadVouchtempcomInfo(FileUploadRequest fileUploadRequest,String type);
	

}
